@@ -5,6 +5,7 @@
 #
 
 use IO::File;
+use File::Basename;
 
 $main::hostname= $ARGV[0];
 $main::sdkpath= $ARGV[1];
@@ -549,15 +550,26 @@ sub resolveLink
 {
     my $base= shift;
     my $link= shift;
-    my $linktarget =  readlink "$base/$link"; 
+
+    my $resolvedpath = "$base/$link";
+    my $linktarget =  readlink "$resolvedpath"; 
     my $resolvedlink = "";
 
     while ( $linktarget ne "") {
-    $link = $linktarget;
-    $linktarget = readlink "$base/$link";
+
+    if ( $linktarget =~ m/^\/.*/ )
+    {
+        $resolvedpath = "$linktarget";
+    } else {
+        $resolvedpath = `cd $base/$linktarget; pwd`;
+        chop $resolvedpath;
+    }
+    $base = dirname("$resolvedpath");
+
+    $linktarget = readlink "$resolvedpath";
     }
 
-    $resolvedlink = `cd $base/$link; pwd`;
+    $resolvedlink = `cd $resolvedpath; pwd`;
     chop $resolvedlink;
     return $resolvedlink;
 }
@@ -573,6 +585,7 @@ sub searchprog
     {
         if ( $main::operatingSystem =~ m/darwin/ ) {
             $progDir = resolveLink("/System/Library/Frameworks/JavaVM.Framework/Versions", "CurrentJDK");
+
             if ( -e "$progDir/$main::OO_SDK_JAVA_BIN_DIR/javac" )
             {
                 return "$progDir/$main::OO_SDK_JAVA_BIN_DIR";
@@ -636,9 +649,9 @@ sub searchMacOffice
 
 sub searchoffice
 {
-    my $offset = rindex($main::sdkpath, "/openoffice.org");
+    my $offset = rindex($main::sdkpath, "/libreoffice");
     my $tmpOffice = substr($main::sdkpath, 0, $offset);
-    my $officepath = "$tmpOffice/openoffice.org$main::OO_MAJORVERSION";
+    my $officepath = "$tmpOffice/libreoffice";
 
 #	if ( $main::OO_MINORVERSION > 0) {
 #		$officepath = "$officepath$main::OO_MINORVERSION";
